@@ -1,5 +1,4 @@
 <?php
-
 /* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */
 
 /**
@@ -19,12 +18,14 @@
  * is" without express or implied warranty.
  *
  * @author     Ryuma Ando <ando@ecomas.co.jp>
- * @copyright  2003-2013 PgPool Global Development Group
+ * @copyright  2003-2015 PgPool Global Development Group
  * @version    CVS: $Id$
  */
 
 $pgpoolConfigParam = array();
 $pgpoolConfigBackendParam = array();
+$pgpoolConfigWdOtherParam = array();
+$pgpoolConfigHbDestinationParam = array();
 
 define('NUM_MAX', 65535);
 
@@ -35,7 +36,6 @@ $hostreg    = '^[0-9a-zA-Z\._\-]*$';
 $sslreg     = '^(|\/[0-9a-zA-Z_\/\.\-]*)$';
 $commandreg = '^[0-9a-zA-Z_\/\.\-]*$';
 $addressreg = '^([0-9a-zA-Z\._\-]+|[\*]{1})$';
-$addressreg = '^([0-9a-zA-Z\._\-]+|[\*]{1})$';
 $listreg    = '^[0-9a-zA-Z_,]*$';
 $queryreg   = '^[0-9a-zA-Z; ]+$';
 $userreg    = "^[0-9a-zA-Z_\.\-]+$";
@@ -56,30 +56,51 @@ $key = 'listen_addresses';
 $pgpoolConfigParam[$key]['type'] = 'C';
 $pgpoolConfigParam[$key]['default'] = 'localhost';
 $pgpoolConfigParam[$key]['regexp'] = $addressreg;
+$pgpoolConfigParam[$key]['restart'] = TRUE;
 
 $key = 'port';
 $pgpoolConfigParam[$key]['type'] = 'N';
 $pgpoolConfigParam[$key]['default'] = 9999;
 $pgpoolConfigParam[$key]['max'] = NUM_MAX;
 $pgpoolConfigParam[$key]['min'] = 1024;
+$pgpoolConfigParam[$key]['restart'] = TRUE;
 
 $key = 'socket_dir';
 $pgpoolConfigParam[$key]['type'] = 'C';
 $pgpoolConfigParam[$key]['default'] = '/tmp';
 $pgpoolConfigParam[$key]['regexp'] = $dirreg;
+$pgpoolConfigParam[$key]['restart'] = TRUE;
+
+$key = 'listen_backlog_multiplier';
+$pgpoolConfigParam[$key]['type'] = 'N';
+$pgpoolConfigParam[$key]['default'] = 2;
+$pgpoolConfigParam[$key]['max'] = NUM_MAX;
+$pgpoolConfigParam[$key]['min'] = 1;
+
+$key = 'serialize_accept';
+$pgpoolConfigParam[$key]['type'] = 'B';
+$pgpoolConfigParam[$key]['default'] = 'off';
 
 # - pgpool Communication Manager Connection Settings -
 
+$key = 'pcp_listen_addresses';
+$pgpoolConfigParam[$key]['type'] = 'C';
+$pgpoolConfigParam[$key]['default'] = 'localhost';
+$pgpoolConfigParam[$key]['regexp'] = $addressreg;
+$pgpoolConfigParam[$key]['restart'] = TRUE;
+
 $key = 'pcp_port';
 $pgpoolConfigParam[$key]['type'] = 'N';
 $pgpoolConfigParam[$key]['default'] = 9898;
 $pgpoolConfigParam[$key]['min'] = 1024;
 $pgpoolConfigParam[$key]['max'] = NUM_MAX;
+$pgpoolConfigParam[$key]['restart'] = TRUE;
 
 $key = 'pcp_socket_dir';
 $pgpoolConfigParam[$key]['type'] = 'C';
 $pgpoolConfigParam[$key]['default'] = '/tmp';
 $pgpoolConfigParam[$key]['regexp'] = $dirreg;
+$pgpoolConfigParam[$key]['restart'] = TRUE;
 
 # - Backend Connection Settings -
 
@@ -87,28 +108,34 @@ $key = 'backend_hostname';
 $pgpoolConfigBackendParam[$key]['type'] = 'C';
 $pgpoolConfigBackendParam[$key]['default'] = '';
 $pgpoolConfigBackendParam[$key]['regexp'] = $hostreg;
+$pgpoolConfigBackendParam[$key]['multiple'] = TRUE;
 
 $key = 'backend_port';
 $pgpoolConfigBackendParam[$key]['type'] = 'N';
 $pgpoolConfigBackendParam[$key]['default'] = 5432;
 $pgpoolConfigBackendParam[$key]['min'] = 1024;
 $pgpoolConfigBackendParam[$key]['max'] = NUM_MAX;
+$pgpoolConfigBackendParam[$key]['multiple'] = TRUE;
 
 $key = 'backend_weight';
 $pgpoolConfigBackendParam[$key]['type'] = 'F';
 $pgpoolConfigBackendParam[$key]['default'] = 1;
 $pgpoolConfigBackendParam[$key]['min'] = 0.0;
 $pgpoolConfigBackendParam[$key]['max'] = 100.0;
+$pgpoolConfigBackendParam[$key]['multiple'] = TRUE;
 
 $key = 'backend_data_directory';
 $pgpoolConfigBackendParam[$key]['type'] = 'C';
 $pgpoolConfigBackendParam[$key]['default'] = '';
 $pgpoolConfigBackendParam[$key]['regexp'] = $anyelse;
+$pgpoolConfigBackendParam[$key]['multiple'] = TRUE;
 
 $key = 'backend_flag';
 $pgpoolConfigBackendParam[$key]['type'] = 'C';
 $pgpoolConfigBackendParam[$key]['default'] = 'ALLOW_TO_FAILOVER';
-$pgpoolConfigBackendParam[$key]['regexp'] = selectreg(array('ALLOW_TO_FAILOVER', 'DISALLOW_TO_FAILOVER'));
+$pgpoolConfigBackendParam[$key]['select'] = array('ALLOW_TO_FAILOVER', 'DISALLOW_TO_FAILOVER');
+$pgpoolConfigBackendParam[$key]['regexp'] = selectreg($pgpoolConfigBackendParam[$key]['select']);
+$pgpoolConfigBackendParam[$key]['multiple'] = TRUE;
 
 # - Authentication -
 
@@ -132,26 +159,35 @@ $pgpoolConfigParam[$key]['max'] = 10000;
 $key = 'ssl';
 $pgpoolConfigParam[$key]['type'] = 'B';
 $pgpoolConfigParam[$key]['default'] = 'off';
+$pgpoolConfigParam[$key]['restart'] = TRUE;
 
 $key = 'ssl_key';
 $pgpoolConfigParam[$key]['type'] = 'C';
 $pgpoolConfigParam[$key]['default'] = '';
 $pgpoolConfigParam[$key]['regexp'] = $sslreg;
+$pgpoolConfigParam[$key]['restart'] = TRUE;
+$pgpoolConfigParam[$key]['parent'] = array('ssl' => 'on');
 
 $key = 'ssl_cert';
 $pgpoolConfigParam[$key]['type'] = 'C';
 $pgpoolConfigParam[$key]['default'] = '';
 $pgpoolConfigParam[$key]['regexp'] = $sslreg;
+$pgpoolConfigParam[$key]['restart'] = TRUE;
+$pgpoolConfigParam[$key]['parent'] = array('ssl' => 'on');
 
 $key = 'ssl_ca_cert';
 $pgpoolConfigParam[$key]['type'] = 'C';
 $pgpoolConfigParam[$key]['default'] = '';
 $pgpoolConfigParam[$key]['regexp'] = $sslreg;
+$pgpoolConfigParam[$key]['restart'] = TRUE;
+$pgpoolConfigParam[$key]['parent'] = array('ssl' => 'on');
 
 $key = 'ssl_ca_cert_dir';
 $pgpoolConfigParam[$key]['type'] = 'C';
 $pgpoolConfigParam[$key]['default'] = '';
 $pgpoolConfigParam[$key]['regexp'] = $sslreg;
+$pgpoolConfigParam[$key]['restart'] = TRUE;
+$pgpoolConfigParam[$key]['parent'] = array('ssl' => 'on');
 
 #------------------------------------------------------------------------------
 # POOLS
@@ -164,12 +200,14 @@ $pgpoolConfigParam[$key]['type'] = 'N';
 $pgpoolConfigParam[$key]['default'] = '32';
 $pgpoolConfigParam[$key]['min'] = 1;
 $pgpoolConfigParam[$key]['max'] = NUM_MAX;
+$pgpoolConfigParam[$key]['restart'] = TRUE;
 
 $key = 'max_pool';
 $pgpoolConfigParam[$key]['type'] = 'N';
 $pgpoolConfigParam[$key]['default'] = 4;
 $pgpoolConfigParam[$key]['min'] = 1;
 $pgpoolConfigParam[$key]['max'] = NUM_MAX;
+$pgpoolConfigParam[$key]['restart'] = TRUE;
 
 # - Life time -
 
@@ -206,13 +244,20 @@ $pgpoolConfigParam[$key]['max'] = NUM_MAX;
 $key = 'log_destination';
 $pgpoolConfigParam[$key]['type'] = 'C';
 $pgpoolConfigParam[$key]['default'] = 'stderr';
-$pgpoolConfigParam[$key]['regexp'] = selectreg(array('stderr', 'syslog'));
+$pgpoolConfigParam[$key]['select'] = array('stderr', 'syslog');
+$pgpoolConfigParam[$key]['regexp'] = selectreg($pgpoolConfigParam[$key]['select']);
 
 # - What to log -
 
+$key = 'log_line_prefix';
+$pgpoolConfigParam[$key]['type'] = 'C';
+$pgpoolConfigParam[$key]['default'] = '';
+$pgpoolConfigParam[$key]['regexp'] = $anyelse;
+
 $key = 'print_timestamp';
 $pgpoolConfigParam[$key]['type'] = 'B';
 $pgpoolConfigParam[$key]['default'] = 'on';
+$pgpoolConfigParam[$key]['restart'] = TRUE;
 
 $key = 'log_connections';
 $pgpoolConfigParam[$key]['type'] = 'B';
@@ -233,19 +278,22 @@ $pgpoolConfigParam[$key]['default'] = 'off';
 $key = 'log_standby_delay';
 $pgpoolConfigParam[$key]['type'] = 'C';
 $pgpoolConfigParam[$key]['default'] = 'none';
-$pgpoolConfigParam[$key]['regexp'] = selectreg(array('always', 'if_over_threshold', 'none'));
+$pgpoolConfigParam[$key]['select'] = array('always', 'if_over_threshold', 'none');
+$pgpoolConfigParam[$key]['regexp'] = selectreg($pgpoolConfigParam[$key]['select']);
 
-# - Syslog specific - 
+# - Syslog specific -
 
 $key = 'syslog_facility';
-$pgpoolConfigBackendParam[$key]['type'] = 'C';
-$pgpoolConfigBackendParam[$key]['default'] = 'LOCAL0';
-$pgpoolConfigBackendParam[$key]['regexp'] = $strreg;
+$pgpoolConfigParam[$key]['type'] = 'C';
+$pgpoolConfigParam[$key]['default'] = 'LOCAL0';
+$pgpoolConfigParam[$key]['regexp'] = $strreg;
+$pgpoolConfigParam[$key]['parent'] = array('log_destination' => 'syslog');
 
 $key = 'syslog_ident';
-$pgpoolConfigBackendParam[$key]['type'] = 'C';
-$pgpoolConfigBackendParam[$key]['default'] = 'pgpool';
-$pgpoolConfigBackendParam[$key]['regexp'] = $strreg;
+$pgpoolConfigParam[$key]['type'] = 'C';
+$pgpoolConfigParam[$key]['default'] = 'pgpool';
+$pgpoolConfigParam[$key]['regexp'] = $strreg;
+$pgpoolConfigParam[$key]['parent'] = array('log_destination' => 'syslog');
 
 # - Debug -
 
@@ -255,6 +303,30 @@ $pgpoolConfigParam[$key]['default'] = '0';
 $pgpoolConfigParam[$key]['min'] = 0;
 $pgpoolConfigParam[$key]['max'] = NUM_MAX;
 
+$key = 'log_error_verbosity';
+$pgpoolConfigParam[$key]['type'] = 'C';
+$pgpoolConfigParam[$key]['default'] = 'DEFAULT';
+$pgpoolConfigParam[$key]['select'] = array('TERSE', 'DEFAULT', 'VERBOSE');
+$pgpoolConfigParam[$key]['regexp'] = selectreg($pgpoolConfigParam[$key]['select']);
+
+$key = 'client_min_messages';
+$pgpoolConfigParam[$key]['type'] = 'C';
+$pgpoolConfigParam[$key]['default'] = 'notice';
+$pgpoolConfigParam[$key]['select'] = array(
+    'debug5', 'debug4', 'debug3', 'debug2', 'debug1',
+    'log', 'notice', 'warning', 'error'
+);
+$pgpoolConfigParam[$key]['regexp'] = selectreg($pgpoolConfigParam[$key]['select']);
+
+$key = 'log_min_messages';
+$pgpoolConfigParam[$key]['type'] = 'C';
+$pgpoolConfigParam[$key]['default'] = 'warning';
+$pgpoolConfigParam[$key]['select'] = array(
+    'debug5', 'debug4', 'debug3', 'debug2', 'debug1',
+    'info', 'notice', 'warning', 'error', 'log', 'fatal', 'panic'
+);
+$pgpoolConfigParam[$key]['regexp'] = selectreg($pgpoolConfigParam[$key]['select']);
+
 #------------------------------------------------------------------------------
 # FILE LOCATIONS
 #------------------------------------------------------------------------------
@@ -263,11 +335,13 @@ $key = 'pid_file_name';
 $pgpoolConfigParam[$key]['type'] = 'C';
 $pgpoolConfigParam[$key]['default'] = '/var/run/pgpool/pgpool.pid';
 $pgpoolConfigParam[$key]['regexp'] = $dirreg;
+$pgpoolConfigParam[$key]['restart'] = TRUE;
 
 $key = 'logdir';
 $pgpoolConfigParam[$key]['type'] = 'C';
 $pgpoolConfigParam[$key]['default'] = '/tmp';
 $pgpoolConfigParam[$key]['regexp'] = $dirreg;
+$pgpoolConfigParam[$key]['restart'] = TRUE;
 
 #------------------------------------------------------------------------------
 # CONNECTION POOLING
@@ -276,6 +350,7 @@ $pgpoolConfigParam[$key]['regexp'] = $dirreg;
 $key = 'connection_cache';
 $pgpoolConfigParam[$key]['type'] = 'B';
 $pgpoolConfigParam[$key]['default'] =true;
+$pgpoolConfigParam[$key]['restart'] = TRUE;
 
 $key = 'reset_query_list';
 $pgpoolConfigParam[$key]['type'] = 'C';
@@ -289,29 +364,35 @@ $pgpoolConfigParam[$key]['regexp'] = $queryreg;
 $key = 'replication_mode';
 $pgpoolConfigParam[$key]['type'] = 'B';
 $pgpoolConfigParam[$key]['default'] = 'off';
+$pgpoolConfigParam[$key]['restart'] = TRUE;
 
 $key = 'replicate_select';
 $pgpoolConfigParam[$key]['type'] = 'B';
 $pgpoolConfigParam[$key]['default'] = 'off';
+$pgpoolConfigParam[$key]['parent'] = array('replication_mode' => 'on');
 
 $key = 'insert_lock';
 $pgpoolConfigParam[$key]['type'] = 'B';
 $pgpoolConfigParam[$key]['default'] = 'off';
+$pgpoolConfigParam[$key]['parent'] = array('replication_mode' => 'on');
 
 $key = 'lobj_lock_table';
 $pgpoolConfigParam[$key]['type'] = 'C';
 $pgpoolConfigParam[$key]['default'] = '';
 $pgpoolConfigParam[$key]['regexp'] = $anyelse;
+$pgpoolConfigParam[$key]['parent'] = array('replication_mode' => 'on');
 
 # - Degenerate handling -
 
 $key = 'replication_stop_on_mismatch';
 $pgpoolConfigParam[$key]['type'] = 'B';
 $pgpoolConfigParam[$key]['default'] = 'off';
+$pgpoolConfigParam[$key]['parent'] = array('replication_mode' => 'on');
 
 $key = 'failover_if_affected_tuples_mismatch';
 $pgpoolConfigParam[$key]['type'] = 'B';
 $pgpoolConfigParam[$key]['default'] = 'off';
+$pgpoolConfigParam[$key]['parent'] = array('replication_mode' => 'on');
 
 #------------------------------------------------------------------------------
 # LOAD BALANCING MODE
@@ -320,20 +401,41 @@ $pgpoolConfigParam[$key]['default'] = 'off';
 $key = 'load_balance_mode';
 $pgpoolConfigParam[$key]['type'] = 'B';
 $pgpoolConfigParam[$key]['default'] = 'off';
+$pgpoolConfigParam[$key]['restart'] = TRUE;
 
 $key = 'ignore_leading_white_space';
 $pgpoolConfigParam[$key]['type'] = 'B';
 $pgpoolConfigParam[$key]['default'] = true;
+$pgpoolConfigParam[$key]['parent'] = array('load_balance_mode' => 'on');
 
 $key = 'white_function_list';
 $pgpoolConfigParam[$key]['type'] = 'C';
 $pgpoolConfigParam[$key]['default'] = '';
 $pgpoolConfigParam[$key]['regexp'] = $anyelse;
+$pgpoolConfigParam[$key]['parent'] = array('load_balance_mode' => 'on');
 
 $key = 'black_function_list';
 $pgpoolConfigParam[$key]['type'] = 'C';
 $pgpoolConfigParam[$key]['default'] = '';
 $pgpoolConfigParam[$key]['regexp'] = $anyelse;
+$pgpoolConfigParam[$key]['parent'] = array('load_balance_mode' => 'on');
+
+$key = 'database_redirect_preference_list';
+$pgpoolConfigParam[$key]['type'] = 'C';
+$pgpoolConfigParam[$key]['default'] = '';
+$pgpoolConfigParam[$key]['regexp'] = $anyelse;
+$pgpoolConfigParam[$key]['parent'] = array('load_balance_mode' => 'on');
+
+$key = 'app_name_redirect_preference_list';
+$pgpoolConfigParam[$key]['type'] = 'C';
+$pgpoolConfigParam[$key]['default'] = '';
+$pgpoolConfigParam[$key]['regexp'] = $anyelse;
+$pgpoolConfigParam[$key]['parent'] = array('load_balance_mode' => 'on');
+
+$key = 'allow_sql_comments';
+$pgpoolConfigParam[$key]['type'] = 'B';
+$pgpoolConfigParam[$key]['default'] = 'off';
+$pgpoolConfigParam[$key]['parent'] = array('load_balance_mode' => 'on');
 
 #------------------------------------------------------------------------------
 # MASTER/SLAVE MODE
@@ -342,11 +444,15 @@ $pgpoolConfigParam[$key]['regexp'] = $anyelse;
 $key = 'master_slave_mode';
 $pgpoolConfigParam[$key]['type'] = 'B';
 $pgpoolConfigParam[$key]['default'] = 'off';
+$pgpoolConfigParam[$key]['restart'] = TRUE;
 
 $key = 'master_slave_sub_mode';
 $pgpoolConfigParam[$key]['type'] = 'C';
 $pgpoolConfigParam[$key]['default'] = 'slony';
-$pgpoolConfigParam[$key]['regexp'] = selectreg(array('slony', 'stream'));
+$pgpoolConfigParam[$key]['select'] = array('slony', 'stream');
+$pgpoolConfigParam[$key]['regexp'] = selectreg($pgpoolConfigParam[$key]['select']);
+$pgpoolConfigParam[$key]['restart'] = TRUE;
+$pgpoolConfigParam[$key]['parent'] = array('master_slave_mode' => 'on');
 
 # - Streaming -
 
@@ -355,28 +461,39 @@ $pgpoolConfigParam[$key]['type'] = 'N';
 $pgpoolConfigParam[$key]['default'] = 0;
 $pgpoolConfigParam[$key]['min'] = 0;
 $pgpoolConfigParam[$key]['max'] = NUM_MAX;
+$pgpoolConfigParam[$key]['parent'] = array('master_slave_mode' => 'on', 'master_slave_sub_mode' => 'stream');
 
 $key = 'sr_check_user';
 $pgpoolConfigParam[$key]['type'] = 'C';
 $pgpoolConfigParam[$key]['default'] = '';
 $pgpoolConfigParam[$key]['regexp'] = $listreg;
+$pgpoolConfigParam[$key]['parent'] = array('master_slave_mode' => 'on', 'master_slave_sub_mode' => 'stream');
 
 $key = 'sr_check_password';
 $pgpoolConfigParam[$key]['type'] = 'C';
 $pgpoolConfigParam[$key]['default'] = '';
 $pgpoolConfigParam[$key]['regexp'] = $listreg;
+$pgpoolConfigParam[$key]['parent'] = array('master_slave_mode' => 'on', 'master_slave_sub_mode' => 'stream');
+
+$key = 'sr_check_database';
+$pgpoolConfigParam[$key]['type'] = 'C';
+$pgpoolConfigParam[$key]['default'] = '';
+$pgpoolConfigParam[$key]['regexp'] = $listreg;
+$pgpoolConfigParam[$key]['parent'] = array('master_slave_mode' => 'on', 'master_slave_sub_mode' => 'stream');
 
 $key = 'delay_threshold';
 $pgpoolConfigParam[$key]['type'] = 'N';
 $pgpoolConfigParam[$key]['default'] = 0;
 $pgpoolConfigParam[$key]['min'] = 0;
 $pgpoolConfigParam[$key]['max'] = NUM_MAX;
+$pgpoolConfigParam[$key]['parent'] = array('master_slave_mode' => 'on', 'master_slave_sub_mode' => 'stream');
 
 # - Special commands -
 $key = 'follow_master_command';
 $pgpoolConfigParam[$key]['type'] = 'C';
 $pgpoolConfigParam[$key]['default'] = '';
 $pgpoolConfigParam[$key]['regexp'] = $anyelse;
+$pgpoolConfigParam[$key]['parent'] = array('master_slave_mode' => 'on');
 
 #------------------------------------------------------------------------------
 # PARALLEL MODE AND QUERY CACHE
@@ -385,15 +502,20 @@ $pgpoolConfigParam[$key]['regexp'] = $anyelse;
 $key = 'parallel_mode';
 $pgpoolConfigParam[$key]['type'] = 'B';
 $pgpoolConfigParam[$key]['default'] = 'off';
+$pgpoolConfigParam[$key]['restart'] = TRUE;
 
 $key = 'enable_query_cache';
 $pgpoolConfigParam[$key]['type'] = 'B';
 $pgpoolConfigParam[$key]['default'] = 'off';
+$pgpoolConfigParam[$key]['restart'] = TRUE;
+$pgpoolConfigParam[$key]['parent'] = array('parallel_mode' => 'on');
 
 $key = 'pgpool2_hostname';
 $pgpoolConfigParam[$key]['type'] = 'C';
 $pgpoolConfigParam[$key]['default'] = 'localhost';
 $pgpoolConfigParam[$key]['regexp'] = $hostreg;
+$pgpoolConfigParam[$key]['restart'] = TRUE;
+$pgpoolConfigParam[$key]['parent'] = array('parallel_mode' => 'on');
 
 # - System DB info -
 
@@ -401,32 +523,44 @@ $key = 'system_db_hostname';
 $pgpoolConfigParam[$key]['type'] = 'C';
 $pgpoolConfigParam[$key]['default'] = 'system_db_hostname';
 $pgpoolConfigParam[$key]['regexp'] = $hostreg;
+$pgpoolConfigParam[$key]['restart'] = TRUE;
+$pgpoolConfigParam[$key]['parent'] = array('parallel_mode' => 'on');
 
 $key = 'system_db_port';
 $pgpoolConfigParam[$key]['type'] = 'N';
 $pgpoolConfigParam[$key]['default'] = 5432;
 $pgpoolConfigParam[$key]['min'] = 1024;
 $pgpoolConfigParam[$key]['max'] = NUM_MAX;
+$pgpoolConfigParam[$key]['restart'] = TRUE;
+$pgpoolConfigParam[$key]['parent'] = array('parallel_mode' => 'on');
 
 $key = 'system_db_dbname';
 $pgpoolConfigParam[$key]['type'] = 'C';
 $pgpoolConfigParam[$key]['default'] = 'pgpool';
 $pgpoolConfigParam[$key]['regexp'] = $strreg;
+$pgpoolConfigParam[$key]['restart'] = TRUE;
+$pgpoolConfigParam[$key]['parent'] = array('parallel_mode' => 'on');
 
 $key = 'system_db_schema';
 $pgpoolConfigParam[$key]['type'] = 'C';
 $pgpoolConfigParam[$key]['default'] = 'pgpool_catalog';
 $pgpoolConfigParam[$key]['regexp'] = $strreg;
+$pgpoolConfigParam[$key]['restart'] = TRUE;
+$pgpoolConfigParam[$key]['parent'] = array('parallel_mode' => 'on');
 
 $key = 'system_db_user';
 $pgpoolConfigParam[$key]['type'] = 'C';
 $pgpoolConfigParam[$key]['default'] = 'pgpool';
 $pgpoolConfigParam[$key]['regexp'] = $userreg;
+$pgpoolConfigParam[$key]['restart'] = TRUE;
+$pgpoolConfigParam[$key]['parent'] = array('parallel_mode' => 'on');
 
 $key = 'system_db_password';
 $pgpoolConfigParam[$key]['type'] = 'C';
 $pgpoolConfigParam[$key]['default'] = '';
 $pgpoolConfigParam[$key]['regexp'] = $anyelse;
+$pgpoolConfigParam[$key]['restart'] = TRUE;
+$pgpoolConfigParam[$key]['parent'] = array('parallel_mode' => 'on');
 
 #------------------------------------------------------------------------------
 # HEALTH CHECK
@@ -454,6 +588,11 @@ $pgpoolConfigParam[$key]['type'] = 'C';
 $pgpoolConfigParam[$key]['default'] = '';
 $pgpoolConfigParam[$key]['regexp'] = $anyelse;
 
+$key = 'health_check_database';
+$pgpoolConfigParam[$key]['type'] = 'C';
+$pgpoolConfigParam[$key]['default'] = '';
+$pgpoolConfigParam[$key]['regexp'] = $anyelse;
+
 $key = 'health_check_max_retries';
 $pgpoolConfigParam[$key]['type'] = 'N';
 $pgpoolConfigParam[$key]['default'] = 0;
@@ -466,6 +605,12 @@ $pgpoolConfigParam[$key]['default'] = 1;
 $pgpoolConfigParam[$key]['min'] = 0;
 $pgpoolConfigParam[$key]['max'] = NUM_MAX;
 
+$key = 'connect_timeout';
+$pgpoolConfigParam[$key]['type'] = 'N';
+$pgpoolConfigParam[$key]['default'] = 10000;
+$pgpoolConfigParam[$key]['min'] = 0;
+$pgpoolConfigParam[$key]['max'] = NUM_MAX;
+
 #------------------------------------------------------------------------------
 # FAILOVER AND FAILBACK
 #-----------------------------------------------------------------------------
@@ -484,6 +629,12 @@ $key = 'fail_over_on_backend_error';
 $pgpoolConfigParam[$key]['type'] = 'B';
 $pgpoolConfigParam[$key]['default'] = 'on';
 
+$key = 'search_primary_node_timeout';
+$pgpoolConfigParam[$key]['type'] = 'N';
+$pgpoolConfigParam[$key]['default'] = 10;
+$pgpoolConfigParam[$key]['min'] = 0;
+$pgpoolConfigParam[$key]['max'] = NUM_MAX;
+
 #------------------------------------------------------------------------------
 # ONLINE RECOVERY
 #------------------------------------------------------------------------------
@@ -524,101 +675,256 @@ $pgpoolConfigParam[$key]['max'] = NUM_MAX;
 # WATCHDOG
 #------------------------------------------------------------------------------
 
+# Enabling
+
 $key = 'use_watchdog';
 $pgpoolConfigParam[$key]['type'] = 'B';
 $pgpoolConfigParam[$key]['default'] = 'off';
 
-$key = 'trusted_servers';
-$pgpoolConfigParam[$key]['type'] = 'C';
-$pgpoolConfigParam[$key]['default'] = '';
-$pgpoolConfigParam[$key]['regexp'] = $anyelse;
-
-$key = 'delegate_IP';
-$pgpoolConfigParam[$key]['type'] = 'C';
-$pgpoolConfigParam[$key]['default'] = '';
-$pgpoolConfigParam[$key]['regexp'] = $addressreg;
-$pgpoolConfigParam[$key]['null_ok'] = TRUE;
+# Watchdog communication
 
 $key = 'wd_hostname';
 $pgpoolConfigParam[$key]['type'] = 'C';
 $pgpoolConfigParam[$key]['default'] = '';
-$pgpoolConfigParam[$key]['regexp'] = $addressreg;
+$pgpoolConfigParam[$key]['regexp'] = $hostreg;
 $pgpoolConfigParam[$key]['null_ok'] = TRUE;
+$pgpoolConfigParam[$key]['parent'] = array('use_watchdog' => 'on');
 
 $key = 'wd_port';
 $pgpoolConfigParam[$key]['type'] = 'N';
 $pgpoolConfigParam[$key]['default'] = 9000;
 $pgpoolConfigParam[$key]['max'] = NUM_MAX;
 $pgpoolConfigParam[$key]['min'] = 1024;
+$pgpoolConfigParam[$key]['parent'] = array('use_watchdog' => 'on');
+
+$key = 'wd_priority';
+$pgpoolConfigParam[$key]['type'] = 'N';
+$pgpoolConfigParam[$key]['default'] = 1;
+$pgpoolConfigParam[$key]['min'] = 0;
+$pgpoolConfigParam[$key]['max'] = NUM_MAX;
+$pgpoolConfigParam[$key]['parent'] = array('use_watchdog' => 'on');
+
+$key = 'wd_authkey';
+$pgpoolConfigParam[$key]['type'] = 'C';
+$pgpoolConfigParam[$key]['default'] = '';
+$pgpoolConfigParam[$key]['regexp'] = $anyelse;
+$pgpoolConfigParam[$key]['null_ok'] = TRUE;
+$pgpoolConfigParam[$key]['parent'] = array('use_watchdog' => 'on');
+
+$key = 'wd_ipc_socket_dir';
+$pgpoolConfigParam[$key]['type'] = 'C';
+$pgpoolConfigParam[$key]['default'] = '/tmp';
+$pgpoolConfigParam[$key]['regexp'] = $anyelse;
+$pgpoolConfigParam[$key]['null_ok'] = TRUE;
+$pgpoolConfigParam[$key]['parent'] = array('use_watchdog' => 'on');
+
+# Connection to up stream servers
+
+$key = 'trusted_servers';
+$pgpoolConfigParam[$key]['type'] = 'C';
+$pgpoolConfigParam[$key]['default'] = '';
+$pgpoolConfigParam[$key]['regexp'] = $anyelse;
+$pgpoolConfigParam[$key]['parent'] = array('use_watchdog' => 'on');
+
+$key = 'ping_path';
+$pgpoolConfigParam[$key]['type'] = 'C';
+$pgpoolConfigParam[$key]['default'] = '';
+$pgpoolConfigParam[$key]['regexp'] = $anyelse;
+$pgpoolConfigParam[$key]['parent'] = array('use_watchdog' => 'on');
+
+# Virtual IP control
+
+$key = 'delegate_IP';
+$pgpoolConfigParam[$key]['type'] = 'C';
+$pgpoolConfigParam[$key]['default'] = '';
+$pgpoolConfigParam[$key]['regexp'] = $hostreg;
+$pgpoolConfigParam[$key]['null_ok'] = TRUE;
+$pgpoolConfigParam[$key]['parent'] = array('use_watchdog' => 'on');
+
+$key = 'ifconfig_path';
+$pgpoolConfigParam[$key]['type'] = 'C';
+$pgpoolConfigParam[$key]['default'] = '/sbin';
+$pgpoolConfigParam[$key]['regexp'] = $anyelse;
+$pgpoolConfigParam[$key]['parent'] = array('use_watchdog' => 'on');
+
+$key = 'if_cmd_path';
+$pgpoolConfigParam[$key]['type'] = 'C';
+$pgpoolConfigParam[$key]['default'] = '/sbin';
+$pgpoolConfigParam[$key]['regexp'] = $anyelse;
+$pgpoolConfigParam[$key]['parent'] = array('use_watchdog' => 'on');
+
+$key = 'if_up_cmd';
+$pgpoolConfigParam[$key]['type'] = 'C';
+$pgpoolConfigParam[$key]['default'] = 'ip addr add $_IP_$/24 dev eth0 label eth0:0';
+$pgpoolConfigParam[$key]['regexp'] = $anyelse;
+$pgpoolConfigParam[$key]['parent'] = array('use_watchdog' => 'on');
+
+$key = 'if_down_cmd';
+$pgpoolConfigParam[$key]['type'] = 'C';
+$pgpoolConfigParam[$key]['default'] = 'ip addr del $_IP_$/24 dev eth0';
+$pgpoolConfigParam[$key]['regexp'] = $anyelse;
+$pgpoolConfigParam[$key]['parent'] = array('use_watchdog' => 'on');
+
+$key = 'arping_path';
+$pgpoolConfigParam[$key]['type'] = 'C';
+$pgpoolConfigParam[$key]['default'] = '/usr/sbin';
+$pgpoolConfigParam[$key]['regexp'] = $anyelse;
+$pgpoolConfigParam[$key]['parent'] = array('use_watchdog' => 'on');
+
+$key = 'arping_cmd';
+$pgpoolConfigParam[$key]['type'] = 'C';
+$pgpoolConfigParam[$key]['default'] = 'arping -U $_IP_$ -w 1';
+$pgpoolConfigParam[$key]['regexp'] = $anyelse;
+$pgpoolConfigParam[$key]['parent'] = array('use_watchdog' => 'on');
+
+# Behavior on escalation
+
+$key = 'clear_memqcache_on_escalation';
+$pgpoolConfigParam[$key]['type'] = 'B';
+$pgpoolConfigParam[$key]['default'] = 'on';
+$pgpoolConfigParam[$key]['parent'] = array('use_watchdog' => 'on');
+
+$key = 'wd_escalation_command';
+$pgpoolConfigParam[$key]['type'] = 'C';
+$pgpoolConfigParam[$key]['default'] = '';
+$pgpoolConfigParam[$key]['regexp'] = $anyelse;
+$pgpoolConfigParam[$key]['parent'] = array('use_watchdog' => 'on');
+
+$key = 'wd_de_escalation_command';
+$pgpoolConfigParam[$key]['type'] = 'C';
+$pgpoolConfigParam[$key]['default'] = '';
+$pgpoolConfigParam[$key]['regexp'] = $anyelse;
+$pgpoolConfigParam[$key]['parent'] = array('use_watchdog' => 'on');
+
+$key = 'wd_monitoring_interfaces_list';
+$pgpoolConfigParam[$key]['type'] = 'C';
+$pgpoolConfigParam[$key]['default'] = '';
+$pgpoolConfigParam[$key]['regexp'] = $anyelse;
+$pgpoolConfigParam[$key]['parent'] = array('use_watchdog' => 'on');
+
+# Life checking pgpool-II
+
+# (Common)
+
+$key = 'wd_lifecheck_method';
+$pgpoolConfigParam[$key]['type'] = 'C';
+$pgpoolConfigParam[$key]['default'] = 'heartbeat';
+$pgpoolConfigParam[$key]['select'] = array('heartbeat', 'query');
+$pgpoolConfigParam[$key]['regexp'] = selectreg($pgpoolConfigParam[$key]['select']);
+$pgpoolConfigParam[$key]['parent'] = array('use_watchdog' => 'on');
 
 $key = 'wd_interval';
 $pgpoolConfigParam[$key]['type'] = 'N';
 $pgpoolConfigParam[$key]['default'] = 10;
 $pgpoolConfigParam[$key]['max'] = NUM_MAX;
 $pgpoolConfigParam[$key]['min'] = 0;
+$pgpoolConfigParam[$key]['parent'] = array('use_watchdog' => 'on');
 
-$key = 'ping_path';
-$pgpoolConfigParam[$key]['type'] = 'C';
-$pgpoolConfigParam[$key]['default'] = '';
-$pgpoolConfigParam[$key]['regexp'] = $anyelse;
+# (Configuration of heartbeat mode)
 
-$key = 'ifconfig_path';
-$pgpoolConfigParam[$key]['type'] = 'C';
-$pgpoolConfigParam[$key]['default'] = '';
-$pgpoolConfigParam[$key]['regexp'] = $anyelse;
+$key = 'wd_heartbeat_port';
+$pgpoolConfigParam[$key]['type'] = 'N';
+$pgpoolConfigParam[$key]['default'] = 9694;
+$pgpoolConfigParam[$key]['max'] = NUM_MAX;
+$pgpoolConfigParam[$key]['min'] = 0;
+$pgpoolConfigParam[$key]['parent'] = array('use_watchdog' => 'on', 'wd_lifecheck_method' => 'heartbeat');
 
-$key = 'if_up_cmd';
-$pgpoolConfigParam[$key]['type'] = 'C';
-$pgpoolConfigParam[$key]['default'] = '';
-$pgpoolConfigParam[$key]['regexp'] = $anyelse;
+$key = 'wd_heartbeat_keepalive';
+$pgpoolConfigParam[$key]['type'] = 'N';
+$pgpoolConfigParam[$key]['default'] = 2;
+$pgpoolConfigParam[$key]['max'] = NUM_MAX;
+$pgpoolConfigParam[$key]['min'] = 0;
+$pgpoolConfigParam[$key]['parent'] = array('use_watchdog' => 'on', 'wd_lifecheck_method' => 'heartbeat');
 
-$key = 'if_down_cmd';
-$pgpoolConfigParam[$key]['type'] = 'C';
-$pgpoolConfigParam[$key]['default'] = '';
-$pgpoolConfigParam[$key]['regexp'] = $anyelse;
+$key = 'wd_heartbeat_deadtime';
+$pgpoolConfigParam[$key]['type'] = 'N';
+$pgpoolConfigParam[$key]['default'] = 30;
+$pgpoolConfigParam[$key]['max'] = NUM_MAX;
+$pgpoolConfigParam[$key]['min'] = 0;
+$pgpoolConfigParam[$key]['parent'] = array('use_watchdog' => 'on', 'wd_lifecheck_method' => 'heartbeat');
 
-$key = 'arping_path';
-$pgpoolConfigParam[$key]['type'] = 'C';
-$pgpoolConfigParam[$key]['default'] = '';
-$pgpoolConfigParam[$key]['regexp'] = $anyelse;
+$key = 'heartbeat_destination';
+$pgpoolConfigHbDestinationParam[$key]['type'] = 'C';
+$pgpoolConfigHbDestinationParam[$key]['default'] = '';
+$pgpoolConfigHbDestinationParam[$key]['regexp'] = $hostreg;
+$pgpoolConfigHbDestinationParam[$key]['multiple'] = TRUE;
+$pgpoolConfigHbDestinationParam[$key]['parent'] = array('use_watchdog' => 'on', 'wd_lifecheck_method' => 'heartbeat');
 
-$key = 'arping_cmd';
-$pgpoolConfigParam[$key]['type'] = 'C';
-$pgpoolConfigParam[$key]['default'] = '';
-$pgpoolConfigParam[$key]['regexp'] = $anyelse;
+$key = 'heartbeat_destination_port';
+$pgpoolConfigHbDestinationParam[$key]['type'] = 'N';
+$pgpoolConfigHbDestinationParam[$key]['default'] = 9694;
+$pgpoolConfigHbDestinationParam[$key]['min'] = 1024;
+$pgpoolConfigHbDestinationParam[$key]['max'] = NUM_MAX;
+$pgpoolConfigHbDestinationParam[$key]['multiple'] = TRUE;
+$pgpoolConfigHbDestinationParam[$key]['parent'] = array('use_watchdog' => 'on', 'wd_lifecheck_method' => 'heartbeat');
+
+$key = 'heartbeat_device';
+$pgpoolConfigHbDestinationParam[$key]['type'] = 'C';
+$pgpoolConfigHbDestinationParam[$key]['default'] = 'eth0';
+$pgpoolConfigHbDestinationParam[$key]['regexp'] = $anyelse;
+$pgpoolConfigHbDestinationParam[$key]['multiple'] = TRUE;
+$pgpoolConfigHbDestinationParam[$key]['parent'] = array('use_watchdog' => 'on', 'wd_lifecheck_method' => 'heartbeat');
+
+# (Configuration of query mode)
 
 $key = 'wd_life_point';
 $pgpoolConfigParam[$key]['type'] = 'N';
 $pgpoolConfigParam[$key]['default'] = 3;
 $pgpoolConfigParam[$key]['max'] = NUM_MAX;
 $pgpoolConfigParam[$key]['min'] = 0;
+$pgpoolConfigParam[$key]['parent'] = array('use_watchdog' => 'on', 'wd_lifecheck_method' => 'query');
 
 $key = 'wd_lifecheck_query';
 $pgpoolConfigParam[$key]['type'] = 'C';
 $pgpoolConfigParam[$key]['default'] = 'SELECT 1';
 $pgpoolConfigParam[$key]['regexp'] = $anyelse;
+$pgpoolConfigParam[$key]['parent'] = array('use_watchdog' => 'on', 'wd_lifecheck_method' => 'query');
 
-# Other pgpool Connection Settings
+$key = 'wd_lifecheck_dbname';
+$pgpoolConfigParam[$key]['type'] = 'C';
+$pgpoolConfigParam[$key]['default'] = 'template1';
+$pgpoolConfigParam[$key]['regexp'] = $anyelse;
+$pgpoolConfigParam[$key]['parent'] = array('use_watchdog' => 'on', 'wd_lifecheck_method' => 'query');
+
+$key = 'wd_lifecheck_user';
+$pgpoolConfigParam[$key]['type'] = 'C';
+$pgpoolConfigParam[$key]['default'] = 'nobody';
+$pgpoolConfigParam[$key]['regexp'] = $anyelse;
+$pgpoolConfigParam[$key]['parent'] = array('use_watchdog' => 'on', 'wd_lifecheck_method' => 'query');
+
+$key = 'wd_lifecheck_password';
+$pgpoolConfigParam[$key]['type'] = 'C';
+$pgpoolConfigParam[$key]['default'] = '';
+$pgpoolConfigParam[$key]['regexp'] = $anyelse;
+$pgpoolConfigParam[$key]['parent'] = array('use_watchdog' => 'on', 'wd_lifecheck_method' => 'query');
+
+# Servers to monitor
 
 $key = 'other_pgpool_hostname';
 $pgpoolConfigWdOtherParam[$key]['type'] = 'C';
 $pgpoolConfigWdOtherParam[$key]['default'] = '';
 $pgpoolConfigWdOtherParam[$key]['regexp'] = $hostreg;
+$pgpoolConfigWdOtherParam[$key]['multiple'] = TRUE;
+$pgpoolConfigWdOtherParam[$key]['parent'] = array('use_watchdog' => 'on');
 
 $key = 'other_pgpool_port';
 $pgpoolConfigWdOtherParam[$key]['type'] = 'N';
 $pgpoolConfigWdOtherParam[$key]['default'] = 9999;
 $pgpoolConfigWdOtherParam[$key]['min'] = 1024;
 $pgpoolConfigWdOtherParam[$key]['max'] = NUM_MAX;
+$pgpoolConfigWdOtherParam[$key]['multiple'] = TRUE;
+$pgpoolConfigWdOtherParam[$key]['parent'] = array('use_watchdog' => 'on');
 
 $key = 'other_wd_port';
 $pgpoolConfigWdOtherParam[$key]['type'] = 'N';
 $pgpoolConfigWdOtherParam[$key]['default'] = 9000;
 $pgpoolConfigWdOtherParam[$key]['min'] = 1024;
 $pgpoolConfigWdOtherParam[$key]['max'] = NUM_MAX;
+$pgpoolConfigWdOtherParam[$key]['multiple'] = TRUE;
+$pgpoolConfigWdOtherParam[$key]['parent'] = array('use_watchdog' => 'on');
 
 #------------------------------------------------------------------------------
-# ON MEMORY QUERY CACHE
+# IN MEMORY QUERY CACHE
 #------------------------------------------------------------------------------
 
 $key = 'memory_cache_enabled';
@@ -628,67 +934,80 @@ $pgpoolConfigParam[$key]['default'] = 'off';
 $key = 'memqcache_method';
 $pgpoolConfigParam[$key]['type'] = 'C';
 $pgpoolConfigParam[$key]['default'] = 'shmem';
-$pgpoolConfigParam[$key]['regexp'] = selectreg(array('shmem', 'memcached'));
+$pgpoolConfigParam[$key]['select'] = array('shmem', 'memcached');
+$pgpoolConfigParam[$key]['regexp'] = selectreg($pgpoolConfigParam[$key]['select']);
+$pgpoolConfigParam[$key]['parent'] = array('memory_cache_enabled' => 'on');
 
 $key = 'memqcache_memcached_host';
 $pgpoolConfigParam[$key]['type'] = 'C';
 $pgpoolConfigParam[$key]['default'] = 'localhost';
 $pgpoolConfigParam[$key]['regexp'] = $hostreg;
+$pgpoolConfigParam[$key]['parent'] = array('memory_cache_enabled' => 'on');
 
 $key = 'memqcache_memcached_port';
 $pgpoolConfigParam[$key]['type'] = 'N';
 $pgpoolConfigParam[$key]['default'] = 11211;
 $pgpoolConfigParam[$key]['max'] = NUM_MAX;
 $pgpoolConfigParam[$key]['min'] = 1024;
+$pgpoolConfigParam[$key]['parent'] = array('memory_cache_enabled' => 'on');
 
 $key = 'memqcache_total_size';
 $pgpoolConfigParam[$key]['type'] = 'N';
 $pgpoolConfigParam[$key]['default'] = 67108864;
 $pgpoolConfigParam[$key]['max'] = PHP_INT_MAX;
 $pgpoolConfigParam[$key]['min'] = 0;
+$pgpoolConfigParam[$key]['parent'] = array('memory_cache_enabled' => 'on');
 
 $key = 'memqcache_max_num_cache';
 $pgpoolConfigParam[$key]['type'] = 'N';
 $pgpoolConfigParam[$key]['default'] = 1000000;
 $pgpoolConfigParam[$key]['max'] = PHP_INT_MAX;
 $pgpoolConfigParam[$key]['min'] = 0;
+$pgpoolConfigParam[$key]['parent'] = array('memory_cache_enabled' => 'on');
 
 $key = 'memqcache_expire';
 $pgpoolConfigParam[$key]['type'] = 'N';
 $pgpoolConfigParam[$key]['default'] = 0;
 $pgpoolConfigParam[$key]['max'] = NUM_MAX;
 $pgpoolConfigParam[$key]['min'] = 0;
+$pgpoolConfigParam[$key]['parent'] = array('memory_cache_enabled' => 'on');
 
 $key = 'memqcache_auto_cache_invalidation';
 $pgpoolConfigParam[$key]['type'] = 'B';
 $pgpoolConfigParam[$key]['default'] = 'on';
+$pgpoolConfigParam[$key]['parent'] = array('memory_cache_enabled' => 'on');
 
 $key = 'memqcache_maxcache';
 $pgpoolConfigParam[$key]['type'] = 'N';
 $pgpoolConfigParam[$key]['default'] = 409600;
 $pgpoolConfigParam[$key]['max'] = PHP_INT_MAX;
 $pgpoolConfigParam[$key]['min'] = 0;
+$pgpoolConfigParam[$key]['parent'] = array('memory_cache_enabled' => 'on');
 
 $key = 'memqcache_cache_block_size';
 $pgpoolConfigParam[$key]['type'] = 'N';
 $pgpoolConfigParam[$key]['default'] = 1048576;
 $pgpoolConfigParam[$key]['max'] = PHP_INT_MAX;
 $pgpoolConfigParam[$key]['min'] = 512;
+$pgpoolConfigParam[$key]['parent'] = array('memory_cache_enabled' => 'on');
 
 $key = 'memqcache_oiddir';
 $pgpoolConfigParam[$key]['type'] = 'C';
 $pgpoolConfigParam[$key]['default'] = '/var/log/pgpool/oiddir';
 $pgpoolConfigParam[$key]['regexp'] = $dirreg;
+$pgpoolConfigParam[$key]['parent'] = array('memory_cache_enabled' => 'on');
 
 $key = 'white_memqcache_table_list';
 $pgpoolConfigParam[$key]['type'] = 'C';
 $pgpoolConfigParam[$key]['default'] = '';
 $pgpoolConfigParam[$key]['regexp'] = $anyelse;
+$pgpoolConfigParam[$key]['parent'] = array('memory_cache_enabled' => 'on');
 
 $key = 'black_memqcache_table_list';
 $pgpoolConfigParam[$key]['type'] = 'C';
 $pgpoolConfigParam[$key]['default'] = '';
 $pgpoolConfigParam[$key]['regexp'] = $anyelse;
+$pgpoolConfigParam[$key]['parent'] = array('memory_cache_enabled' => 'on');
 
 #------------------------------------------------------------------------------
 # OTHERS
@@ -710,6 +1029,10 @@ $key = 'check_temp_table';
 $pgpoolConfigParam[$key]['type'] = 'B';
 $pgpoolConfigParam[$key]['default'] = 'on';
 
+$key = 'check_unlogged_table';
+$pgpoolConfigParam[$key]['type'] = 'B';
+$pgpoolConfigParam[$key]['default'] = 'on';
+
 #------------------------------------------------------------------------------
 # Deleted
 #------------------------------------------------------------------------------
