@@ -19,7 +19,7 @@
  * is" without express or implied warranty.
  *
  * @author     Ryuma Ando <ando@ecomas.co.jp>
- * @copyright  2003-2013 PgPool Global Development Group
+ * @copyright  2003-2016 PgPool Global Development Group
  * @version    CVS: $Id$
  */
 
@@ -27,7 +27,7 @@ require_once('../version.php');
 
 session_start();
 
-require("defaultParameter.php");
+require_once("defaultParameter.php");
 require_once('setLang.php');
 
 /* --------------------------------------------------------------------- */
@@ -41,6 +41,13 @@ if (isset($_POST['action'])) {
     $action = $_POST['action'];
 }
 
+// check version
+if (isset($_POST['version']) && $_POST['version']) {
+    $version = $_POST['version'];
+} else {
+    $version = NULL;
+}
+
 // check pgpool.conf
 if (isset($_POST['pgpool2_config_file']) && $_POST['pgpool2_config_file']) {
     $pgpool2_config_file = $_POST['pgpool2_config_file'];
@@ -49,7 +56,7 @@ if (isset($_POST['pgpool2_config_file']) && $_POST['pgpool2_config_file']) {
 }
 
 $msgPgpoolConfigFile = '';
-if (!@is_file($pgpool2_config_file)) {
+if (! @is_file($pgpool2_config_file)) {
     $msgPgpoolConfigFile = 'File not found';
     $error = TRUE;
 } else {
@@ -71,7 +78,7 @@ if (isset($_POST['password_file']) && $_POST['password_file']) {
 }
 
 $msgPasswordFile = '';
-if (!@is_file($password_file)) {
+if (! @is_file($password_file)) {
     $msgPasswordFile = 'File not found';
     $error = TRUE;
 } else {
@@ -93,7 +100,7 @@ if (isset($_POST['pgpool_command']) && $_POST['pgpool_command']) {
 }
 
 $msgPgpoolCommand = '';
-if (!@is_file($pgpool_command)) {
+if (! @is_file($pgpool_command)) {
     $msgPgpoolCommand = 'pgpool command not found';
     $error = TRUE;
 } elseif (!is_executable($pgpool_command)) {
@@ -101,7 +108,7 @@ if (!@is_file($pgpool_command)) {
     $error = TRUE;
 }
 
-// check args of pgpool comand
+// check args of pgpool command
 $msgCmdC = '';
 $msgCmdLargeD = '';
 $msgCmdD = '';
@@ -147,21 +154,17 @@ if (!is_dir($pcp_client_dir)) {
     $error = TRUE;
 
 } else {
-    $command = array('pcp_attach_node',
-                     'pcp_detach_node',
-                     'pcp_node_count',
-                     'pcp_node_info',
-                     'pcp_proc_count',
-                     'pcp_proc_info',
-                     'pcp_stop_pgpool',
-                     'pcp_systemdb_info');
+    $commands = getPcpCommands();
 
-    for ($i = 0; $i < count($command); $i++) {
-        if (!@is_file($pcp_client_dir . "/" . $command[$i])) {
-            $msgPcpClientDir = $command[$i] . ' command not found';
+    foreach ($commands as $command) {
+        $command_fullpath = "{$pcp_client_dir}/{$command}";
+
+        if (! @is_file($command_fullpath)) {
+            $msgPcpClientDir = $command . ' command not found';
             $error = TRUE;
-        } elseif (!is_executable($pcp_client_dir . "/" . $command[$i] )) {
-            $msgPcpClientDir = $command[$i] . ' not executable';
+
+        } elseif (!is_executable($command_fullpath)) {
+            $msgPcpClientDir = $command . ' not executable';
             $error = TRUE;
         }
     }
@@ -174,6 +177,19 @@ if (isset($_POST['pcp_hostname']) && $_POST['pcp_hostname']) {
     $pcp_hostname =  _PGPOOL2_PCP_HOSTNAME;
 }
 
+$proc_user_info = posix_getpwuid(posix_geteuid());
+$pcppass_file = "{$proc_user_info['dir']}/.pcppass";
+if (3.5 <= $version) {
+    $msgPcpPassFile = '';
+    if (! is_file($pcppass_file)) {
+        $msgPcpPassFile = 'File not found';
+    } elseif (fileowner($pcppass_file) != $proc_user_info['uid']) {
+        $msgPcpPassFile = 'Invalid owner';
+    } elseif (substr(sprintf('%o', fileperms($pcppass_file)), -4) != '0600') {
+        $msgPcpPassFile = 'Invalid permission';
+    }
+}
+
 $msgPcpTimeout = '';
 if (isset($_POST['pcp_timeout']) && $_POST['pcp_timeout']) {
     $pcp_timeout= $_POST['pcp_timeout'];
@@ -188,6 +204,12 @@ if (isset($_POST['pcp_refreshTime']) && $_POST['pcp_refreshTime']) {
     $pcp_refreshTime =  _PGPOOL2_STATUS_REFRESH_TIME;
 }
 
+$msgPhpPgsql= '';
+if (!extension_loaded('pgsql')){
+    $msgPhpPgsql = 'not installed';
+    $error = TRUE;
+}
+
 /* --------------------------------------------------------------------- */
 /* Write pgmt.conf.php                                                   */
 /* --------------------------------------------------------------------- */
@@ -279,7 +301,8 @@ if (!$error && $action == 'next') {
     <td><select name="version" />
         <?php
         foreach (versions() as $v) {
-            echo '<option value="'. $v. '">'. $v. '</optgroup>';
+            printf('<option value="%s"%s>%s</optgroup>',
+                   $v, ($v == $version) ? ' selected' : NULL, $v);
         }
         ?>
         </select>
@@ -288,6 +311,21 @@ if (!$error && $action == 'next') {
   </tr>
   </table>
 
+<?php
+/* --------------------------------------------------------------------- */
+/* Dependencies                                                          */
+/* --------------------------------------------------------------------- */
+?>
+  <h3><?php echo $message['strDependencies'] ?></h3>
+  <table>
+  <tr>
+    <th><label><?php echo $message['strPgPhp'] ?></label></th>
+    <td>
+    <?php showResult($msgPhpPgsql); ?>
+    </td>
+  </tr>
+  </table>
+
 <?php
 /* --------------------------------------------------------------------- */
 /* Config File                                                           */
@@ -325,37 +363,37 @@ if (!$error && $action == 'next') {
 
   <table>
   <tr>
-    <th><label><?php echo $message['strCmdC'] ?></label></th>
+    <th><label><?php echo $message['strCmdC'] ?> (-c)</label></th>
     <td><input type="checkbox" name="c" />
     <?php showResult($msgCmdC); ?>
     </td>
   </tr>
   <tr>
-    <th><label><?php echo $message['strCmdLargeD'] ?></label></th>
+    <th><label><?php echo $message['strCmdLargeD'] ?> (-D)</label></th>
     <td><input type="checkbox" name="D" />
     <?php showResult($msgCmdLargeD); ?>
     </td>
   </tr>
   <tr>
-    <th><label><?php echo $message['strCmdN'] ?></label></th>
+    <th><label><?php echo $message['strCmdN'] ?> (-n)</label></th>
     <td><input type="checkbox" name="n" />
     <?php showResult($msgCmdN); ?>
     </td>
   </tr>
   <tr>
-    <th><label><?php echo $message['strCmdLargeC'] ?></label></th>
+    <th><label><?php echo $message['strCmdLargeC'] ?> (-C)</label></th>
     <td><input type="checkbox" name="D" />
     <?php showResult($msgCmdLargeC); ?>
     </td>
   </tr>
   <tr>
-    <th><label><?php echo $message['strCmdD'] ?></label></th>
+    <th><label><?php echo $message['strCmdD'] ?> (-d)</label></th>
     <td><input type="checkbox" name="d" />
     <?php showResult($msgCmdD); ?>
     </td>
   </tr>
   <tr>
-    <th><label><?php echo $message['strCmdM'] ?></label></th>
+    <th><label><?php echo $message['strCmdM'] ?> (-m)</label></th>
     <td><select  name="m" />
           <option value="s" selected="selected">smart</optgroup>
           <option value="f">fast</optgroup>
@@ -383,6 +421,10 @@ if (!$error && $action == 'next') {
     <?php showResult($msgPcpHostname); ?>
     </td>
   </tr>
+  <tr id="tr_pcppass">
+    <th><label>.pcppass [V3.5 - ]</label></th>
+    <td><?php echo $pcppass_file; ?>
+    <?php showResult($msgPcpPassFile); ?>
   <tr>
     <th><label><?php echo $message['strPcpTimeout'] ?></label></th>
     <td><input name="pcp_timeout" type="text" value="<?php echo $pcp_timeout?>" size="50" />
@@ -424,7 +466,7 @@ else {
 
 function versions()
 {
-    return array('3.4', '3.3', '3.2', '3.1', '3.0',
+    return array('3.5', '3.4', '3.3', '3.2', '3.1', '3.0',
                  '2.3', '2.2', '2.1', '2.0');
 }
 
@@ -442,3 +484,38 @@ function showResult($msg)
         echo '</td><td><img src="images/ok.gif" alt="ok" />';
     }
 }
+
+/**
+ * Get pcp commands in specified version
+ */
+function getPcpCommands()
+{
+    $commands = array();
+    $commands[] = 'pcp_attach_node';
+    $commands[] = 'pcp_node_count';
+    $commands[] = 'pcp_proc_info';
+    $commands[] = 'pcp_recovery_node';
+    $commands[] = 'pcp_detach_node';
+    $commands[] = 'pcp_node_info';
+    $commands[] = 'pcp_proc_count';
+    $commands[] = 'pcp_stop_pgpool';
+
+    // 3.3 -
+    if (3.3 <= _PGPOOL2_VERSION) {
+        $commands[] = 'pcp_watchdog_info';
+    }
+
+    // 3.1 -
+    if (3.1 <= _PGPOOL2_VERSION) {
+        $commands[] = 'pcp_pool_status';
+        $commands[] = 'pcp_promote_node';
+    }
+
+    // - 3.4
+    if (_PGPOOL2_VERSION <= 3.4) {
+        $commands[] = 'pcp_systemdb_info';
+    }
+
+    return $commands;
+}
+
